@@ -41,9 +41,15 @@ function(d, k, eig = FALSE, add = FALSE, x.ret = FALSE, w)
     }
     points <- points[, 1:k, drop=FALSE]
     points[!is.finite(points)] <- NA
+    ## Goodness of fit
+    ev <- e$values[1:k]
+    ev <- ev[ev > 0]
+    ## GOF for real and all axes
+    GOF <- c(sum(ev)/sum(abs(e$values)),
+             sum(ev)/sum(e$values[e$values > 0]))
     if (eig || x.ret || add) {
         out <- list(points = points, eig = if (eig) e$values,
-                    x = if (x.ret) m, ac = NA, GOF = NA, weights = w,
+                    x = if (x.ret) m, ac = NA, GOF = GOF, weights = w,
                     negaxes = negaxes)
         class(out) <- "wcmdscale"
     }
